==> MarpaX-ESLIF-3.0.30.tar.gz: MarpaX-ESLIF-3.0.30/src/include/marpaESLIF/internal/eslif/L0_join_G1.h <==
#ifndef MARPAESLIF_INTERNAL_ESLIF_L0_JOIN_G1_H
#define MARPAESLIF_INTERNAL_ESLIF_L0_JOIN_G1_H

/* The join between two grammars is the description of symbol */
#define L0_JOIN_G1_META_FALSE                            "false"
#define L0_JOIN_G1_META_TRUE                             "true"
#define L0_JOIN_G1_META_STANDARD_NAME                    "standard name"
#define L0_JOIN_G1_META_QUOTED_NAME                      "quoted name"
#define L0_JOIN_G1_META_QUOTED_STRING                    "quoted string"
#define L0_JOIN_G1_META_CHARACTER_CLASS                  "character class"
#define L0_JOIN_G1_META_REGULAR_EXPRESSION               "regular expression"
#define L0_JOIN_G1_META_BARE_NAME                        "bare name"
#define L0_JOIN_G1_META_BRACKETED_NAME                   "bracketed name"
#define L0_JOIN_G1_META_RESTRICTED_ASCII_GRAPH_NAME      "restricted ascii graph name" /* [[:graph:]] without the = */
#define L0_JOIN_G1_META_LUA_ACTION_NAME                  "lua action name" /* ::lua->luaIdentifier */
#define L0_JOIN_G1_META_OP_DECLARE_ANY_GRAMMAR           "op declare any grammar"
#define L0_JOIN_G1_META_OP_DECLARE_TOP_GRAMMAR           "op declare top grammar"
#define L0_JOIN_G1_META_OP_DECLARE_LEX_GRAMMAR           "op declare lex grammar"
#define L0_JOIN_G1_META_OP_LOOSEN                        "op loosen"
#define L0_JOIN_G1_META_OP_EQUAL_PRIORITY                "op equal priority"
#define L0_JOIN_G1_META_WHITESPACE                       "whitespace"
#define L0_JOIN_G1_META_PERL_COMMENT                     "perl comment"
#define L0_JOIN_G1_META_CPLUSPLUS_COMMENT                "cplusplus comment"
#define L0_JOIN_G1_META_GRAPH_ASCII_NAME                 "graph ascii name"

#endif /* MARPAESLIF_INTERNAL_ESLIF_L0_JOIN_G1_H */

==> MarpaX-ESLIF-6.0.20.tar.gz: MarpaX-ESLIF-6.0.20/src/include/marpaESLIF/internal/eslif/L0_join_G1.h <==
#ifndef MARPAESLIF_INTERNAL_ESLIF_L0_JOIN_G1_H
#define MARPAESLIF_INTERNAL_ESLIF_L0_JOIN_G1_H

/* The join between two grammars is the description of symbol */
#define L0_JOIN_G1_META_FALSE                            "false"
#define L0_JOIN_G1_META_TRUE                             "true"
#define L0_JOIN_G1_META_STANDARD_NAME                    "standard name"
#define L0_JOIN_G1_META_QUOTED_STRING_LITERAL            "quoted string literal"
#define L0_JOIN_G1_META_QUOTED_STRING                    "quoted string"
#define L0_JOIN_G1_META_CHARACTER_CLASS                  "character class"
#define L0_JOIN_G1_META_REGULAR_EXPRESSION               "regular expression"
#define L0_JOIN_G1_META_BARE_NAME                        "bare name"
#define L0_JOIN_G1_META_BRACKETED_NAME                   "bracketed name"
#define L0_JOIN_G1_META_RESTRICTED_ASCII_GRAPH_NAME      "restricted ascii graph name" /* [[:graph:]] without the = */
#define L0_JOIN_G1_META_LUA_ACTION_NAME                  "lua action name" /* ::lua->luaIdentifier */
#define L0_JOIN_G1_META_OP_DECLARE_ANY_GRAMMAR           "op declare any grammar"
#define L0_JOIN_G1_META_OP_DECLARE_TOP_GRAMMAR           "op declare top grammar"
#define L0_JOIN_G1_META_OP_DECLARE_LEX_GRAMMAR           "op declare lex grammar"
#define L0_JOIN_G1_META_OP_LOOSEN                        "op loosen"
#define L0_JOIN_G1_META_OP_EQUAL_PRIORITY                "op equal priority"
#define L0_JOIN_G1_META_WHITESPACE                       "whitespace"
#define L0_JOIN_G1_META_PERL_COMMENT                     "perl comment"
#define L0_JOIN_G1_META_CPLUSPLUS_COMMENT                "cplusplus comment"
#define L0_JOIN_G1_META_GRAPH_ASCII_NAME                 "graph ascii name"
#define L0_JOIN_G1_META_LUA_FUNCBODY_AFTER_LPAREN        "lua funcbody after lparen"

#endif /* MARPAESLIF_INTERNAL_ESLIF_L0_JOIN_G1_H */
